<?php

	//-----------------------------------------------------------------------------
	function puma_auth($_username, $_password) {
		// place here your authentication method, by now only Keycloak and LDAP are supported
		if (AUTH_METHOD=='keycloak') return keycloak_auth($_username, $_password);
		if (AUTH_METHOD=='ldap') return ldap_auth($_username, $_password);
		// this is a trivial passwordless method
		return empty($_username)? false: 'Login OK';
	}

	//-----------------------------------------------------------------------------
	function ldap_auth($_username, $_password) {
		$ldap_error = false;
		$ldap_url = 'ldaps://'.LDAP_SERVER.':636/';
		if (!function_exists('ldap_connect')) {
			$ldap_error = "LDAP module not installed in PHP";
			return $ldap_error;
		}
		$ldap = ldap_connect($ldap_url);
		$ldap_error = "$ldap_url\n";
		if (!$ldap) {
			$ldap_error = "Could not connect to $ldap_url";
			return $ldap_error;
		}
		ldap_set_option($ldap, LDAP_OPT_PROTOCOL_VERSION, 3);
		$password = trim(stripslashes($_password));
		$username = trim(stripslashes($_username));
		if (empty($password)) {
			@ldap_close($ldap);
			$ldap_error = "empty password";
			return $ldap_error;
		}
		if ($ldap) {
			$user_search = ldap_search($ldap, LDAP_DN, "(uid=$username)");
			if (!$user_search) {
				$ldap_error ="Error in search query ($ldap_url): ".ldap_error($ldap);
				return $ldap_error;
			}
			$user_get = ldap_get_entries($ldap, $user_search);
			if (!$user_get) {
				$ldap_error = 'user not found';
				@ldap_close($ldap);
				return $ldap_error;
			}
			$user_entry = ldap_first_entry($ldap, $user_search);
			if (!$user_entry) {
				$ldap_error = 'user not found';
				@ldap_close($ldap);
				return $ldap_error;
			}
			$user_dn = ldap_get_dn($ldap, $user_entry);
			if (!$user_dn) {
				$ldap_error = 'user not found';
				@ldap_close($ldap);
				return $ldap_error;
			}
			if (@ldap_bind($ldap, $user_dn, $password)) {
				$ldap_error = 'alias';
				if ($user_get && $user_get['count']) {
					// $login = array('realname' => $user_get[0]['cn'][0]);
					$ldap_error = 'Login OK';
				}
				@ldap_close($ldap);
			} 
			else {
				$ldap_error = 'Attention! Wrong password, please try again';
				@ldap_close($ldap);
				return $ldap_error;
			}
		} 
		else {
			$ldap_error = 'ldap connection';
		}
		return $ldap_error;
	}

	// ----------------------------------------------------------------
	// check access credentials
	function keycloak_auth() {
		session_start();
		if (!empty($_REQUEST['username'])) {
			$data = "grant_type=password&client_id=".KEYCLOAK_CLIENT_ID."&client_secret=".KEYCLOAK_CLIENT_SECRET."&scope=openid&username={$_REQUEST['username']}&password={$_REQUEST['puma_password']}";
			$headers = array('Content-Type: application/x-www-form-urlencoded');
		}
		else if (!empty($_SESSION['token'])) {
			$data = "grant_type=urn:ietf:params:oauth:grant-type:uma-ticket&audience=customers";
			$headers = array("Authorization: Bearer {$_SESSION['token']}");
		}
		else return 'ERROR: missing login and token';
		$url = KEYCLOAK_HOST.'/auth/realms/'.KEYCLOAK_REALM.'/protocol/openid-connect/token';
		$ch = curl_init();
		curl_setopt($ch, CURLOPT_URL, $url);
		curl_setopt($ch, CURLOPT_POST, true);
		curl_setopt($ch, CURLOPT_POSTFIELDS, $data);
		curl_setopt($ch, CURLOPT_HTTPHEADER, $headers);
		curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
		curl_setopt($ch, CURLOPT_SSL_VERIFYHOST, 0);
		curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);
		$result = curl_exec($ch);
		curl_close($ch);
		$res = json_decode($result);
		if (isset($_REQUEST['debug'])) {echo "<pre>"; print_r($res); echo("</pre>");}
		if (!empty($_REQUEST['username']) && isset($res->access_token)) {
			if (isset($_REQUEST['debug'])) echo $res->access_token."<br>\n";
			$_SESSION['token'] = $res->access_token;
			$_SESSION['time'] = time();
			$_SESSION['expires_in'] = $res->expires_in;
			return 'Login OK';
		}
		else if (isset($res->error_description) && (strpos($res->error_description,'Unknown resource server id')!==false)) return 'Login OK ';
		else if (isset($res->error_description) && (strpos($res->error_description,'Invalid bearer token')!==false) && (time()-$_SESSION['time']>=$_SESSION['expires_in'])) return 'ERROR: Authentication expired';
		if (isset($res->error_description)) return $res->error_description;
		return 'Error: invalid response from '.KEYCLOAK_HOST;
	}

?>
