/*jshint esversion: 6 */ 
/**
 * @file ext-puma.js
 *
 * @copyright 2022 Lucio Zambon
 *
 */

/**
* This is a very basic SVG-Edit extension. It adds 2 custom attribute
* required by PUMA framework.
*/

const name = "puma";
const srcTemplate = document.createElement("template");
const updateTemplate = document.createElement("template");
const precisionTemplate = document.createElement("template");
var precision = 10;
if (document.location.search.indexOf('?')!=-1 && document.location.search.indexOf('precision=')!=-1) {
	precision = document.location.search.split('precision=')[1].split('&')[0];
}
srcTemplate.innerHTML = `<se-input id="datasrc" title="data-src" label="data-src" value="" size="35" onChange="document.getElementById(svgEditor.selectedElement.id).removeAttribute('data-src');document.getElementById(svgEditor.selectedElement.id).setAttribute('data-src',document.getElementById('datasrc').value)"></se-input>`;
updateTemplate.innerHTML = `<se-input id="dataonupdate" title="data-onupdate" label="data-onupdate" size="15" value="" onChange="document.getElementById(svgEditor.selectedElement.id).removeAttribute('data-onupdate');document.getElementById(svgEditor.selectedElement.id).setAttribute('data-onupdate',document.getElementById('dataonupdate').value)"></se-input>`;
precisionTemplate.innerHTML = `<se-input id="precision" title="precision" label="precision" value="${precision}" size="2" onChange="precision = document.getElementById('precision').value - 0;"></se-input>`;
var datasrcVisible = false;
var datasrcId = null;


function mySelected(var1, objArray){
	// console.log('mySelectd()', var1, objArray, defaultSelect, 'objArray.length', objArray.length);
	const { svgCanvas } = svgEditor;
	const { $id } = svgCanvas;
	if (objArray.length) {
		if (!datasrcVisible) {
			$id('tools_top').append(srcTemplate.content.cloneNode(true)); 
			$id('tools_top').append(updateTemplate.content.cloneNode(true)); 
			datasrcVisible = true;
		}
		else {
			document.getElementById("datasrc").style.display = 'block';
			document.getElementById("dataonupdate").style.display = 'block';
		}
		if (objArray.length == 1) {
			datasrcId = objArray[0].id;
			console.log(datasrcId);
			var ds = document.getElementById(datasrcId).getAttribute("data-src");
			if (ds == null) ds = '';
			document.getElementById("datasrc").value = ds;
			var dc = document.getElementById(datasrcId).getAttribute("data-onupdate");
			if (dc == null) dc = '';
			document.getElementById("dataonupdate").value = dc;
		}
	}
	else {
		if (datasrcVisible) {
			document.getElementById("datasrc").style.display = 'none';
			document.getElementById("datasrc").value = '';
			document.getElementById("dataonupdate").style.display = 'none';
			document.getElementById("dataonupdate").value = '';
		}
	}
	if (typeof defaultSelect == 'function') defaultSelect(var1, objArray);
}
const defaultSelect = svgEditor.svgCanvas.bind('selected', mySelected);
export default {
	name,
	init ({ _$ }) {
		const svgEditor = this;
		const { svgCanvas } = svgEditor;
		const { $id } = svgCanvas;
		$id('tools_top').append(precisionTemplate.content.cloneNode(true)); 

		// On leaving click, stop moving.
		document.addEventListener("mouseup", function() {
			precision = document.getElementById('precision').value - 0;
			const el = document.getElementById(datasrcId);
			if (datasrcId != 'svgroot' && el && precision>0) {
				if (el.tagName == 'rect') {
					el.setAttribute('x', Math.round(el.getAttribute('x')/precision)*precision);
					el.setAttribute('y', Math.round(el.getAttribute('y')/precision)*precision);
				}
				else if (el.tagName == 'line') {
					const dx = Math.round((el.getAttribute('x2')-el.getAttribute('x1'))/precision)*precision;
					const dy = Math.round((el.getAttribute('y2')-el.getAttribute('y1'))/precision)*precision;
					el.setAttribute('x1', Math.round(el.getAttribute('x1')/precision)*precision);
					el.setAttribute('y1', Math.round(el.getAttribute('y1')/precision)*precision);
					el.setAttribute('x2', el.getAttribute('x1') - 0 + dx);
					el.setAttribute('y2', el.getAttribute('y1') - 0 + dy);
					// console.log('dx', dx, 'x1', el.getAttribute('x1'), 'x2', el.getAttribute('x2'));
				}
				else if (el.tagName == 'polyline' || el.tagName == 'polygon') {
					var p = el.points.getItem(0);
					var px = p.x - Math.round(p.x/precision)*precision;
					var py = p.y - Math.round(p.y/precision)*precision;
					for (var j=0; j<el.points.length; j++) {
						p = el.points.getItem(j);
						p.x = p.x - px;
						p.y = p.y - py;
						el.points.replaceItem(p,j);
					}
				}
				else if (el.tagName == 'ellipse' || el.tagName == 'circle') {
					el.setAttribute('cx', Math.round(el.getAttribute('cx')/precision)*precision);
					el.setAttribute('cy', Math.round(el.getAttribute('cy')/precision)*precision);
				}
				else if (el.tagName == 'path') {
					var pdata = el.getPathData();
					var p0 = pdata[0].values;
					var dx = p0[0] - Math.round(p0[0]/precision)*precision;
					var dy = p0[1] - Math.round(p0[1]/precision)*precision;
					for (var i=0; i<pdata.length; i++) {
						if (pdata[i].type=="H") {
							pdata[i].values[0] = pdata[i].values[0] - dx;
						}
						else if (pdata[i].type=="V") {
							pdata[i].values[0] = pdata[i].values[0] - dy;
						}
						else if (pdata[i].values.length>1) {
							pdata[i].values[0] = pdata[i].values[0] - dx;
							pdata[i].values[1] = pdata[i].values[1] - dy;
						}
						if (pdata[i].type=="S" || pdata[i].type=="Q") {
							pdata[i].values[2] = pdata[i].values[2] - dx;
							pdata[i].values[3] = pdata[i].values[3] - dy;
						}
						else if (pdata[i].type=="C") {
							pdata[i].values[2] = pdata[i].values[2] - dx;
							pdata[i].values[3] = pdata[i].values[3] - dy;
							pdata[i].values[4] = pdata[i].values[4] - dx;
							pdata[i].values[5] = pdata[i].values[5] - dy;
						}
						else if (pdata[i].type=="A") {
							pdata[i].values[5] = pdata[i].values[5] - dx;
							pdata[i].values[6] = pdata[i].values[6] - dy;
						}
					}
					// console.log('post', pdata);
					el.setPathData(pdata);
				}
			}
			
		});
		return {
			name: svgEditor.i18next.t(`${name}:name`),
		};
	}
};
